@@ -63,8 +63,13 @@ class SummernoteWidget(Textarea):
         """
         Returns media files for django to output
         """
-        css = {"all": ("vendor/summernote/summernote-lite.min.css",)}
-        js = ("vendor/summernote/summernote-lite.min.js", "vendor/summernote/summernote-cleaner.js", "vendor/summernote/init.js")
+        css = {"all": ("vendor/summernote/summernote.min.css",)}
+        js = (
+            "vendor/summernote/django-jquery.js",
+            "vendor/summernote/summernote.min.js",
+            "vendor/summernote/summernote-cleaner.js",
+            "vendor/summernote/init.js",
+        )
 
         return Media(css=css, js=js)
 
